@@ -6,6 +6,20 @@ from . import enums
 from .errors import ErrorCodeEnum, LegacyErrorCodeEnum
 
 
+class EmptyDict:
+    @classmethod
+    def __get_validators__(cls):
+        yield cls.validate
+
+    @classmethod
+    def validate(cls, v):
+        if not isinstance(v, dict):
+            raise TypeError("dict required")
+        if len(v.keys()) > 0:
+            raise ValueError("dict must be empty")
+        return {}
+
+
 class RcsSMSBody(BaseModel):
     title: Optional[str] = Field(max_length=30)
     description: str = Field(max_length=100)
@@ -344,7 +358,7 @@ class RcsInfo(BaseModel):
       - "media" :"maapfile://{fileId}"
     """
 
-    buttons: Optional[List[ButtonInfo]]
+    buttons: Optional[List[ButtonInfo, EmptyDict]]
     """
     # buttons
     GSMA RCC.07의3.6.10.4의 ‘suggestions’ 규격에 준하여 버튼을 구성
@@ -539,7 +553,7 @@ class MessageInfo(BaseModel):
 
     userContact: str = Field(max_length=40)
     chatbotId: str = Field(max_length=40)
-    timeStamp: str = Field(regex=r"^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d{3}\+\d{2}$")
+    timestamp: str = Field(regex=r"^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d{3}\+\d{2}$")
 
 
 class SendInfo(BaseModel):
